==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/de.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Storage invalid" : "Speicher ungültig",
    "Unknown error" : "Unbekannter Fehler",
    "All files" : "Alle Dateien",
    "Recent" : "Aktuelle",
    "File could not be found" : "Datei konnte nicht gefunden werden",
    "Home" : "Home",
    "Close" : "Schließen",
    "Favorites" : "Favoriten",
    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
    "Upload cancelled." : "Hochladen abgebrochen.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, Du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
    "Not enough free space" : "Nicht genügend freier Speicherplatz",
    "Uploading …" : "Lade hoch...",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
    "Actions" : "Aktionen",
    "Download" : "Herunterladen",
    "Rename" : "Umbenennen",
    "Move or copy" : "Verschieben oder kopieren",
    "Target folder" : "Zielordner",
    "Delete" : "Löschen",
    "Disconnect storage" : "Speicher trennen",
    "Unshare" : "Freigabe aufheben",
    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
    "Files" : "Dateien",
    "Details" : "Details",
    "Select" : "Auswählen",
    "Pending" : "Ausstehend",
    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder den Administrator kontaktieren.",
    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
    "{newName} already exists" : "{newName} existiert bereits",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{targetName}\" wird bereits bereits in diesem Ordner benutzt \"{dir}\". Bitte einen anderen Namen verwenden.",
    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden , da diese bereits existiert.",
    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden , da dieser bereits existiert",
    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\"",
    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "{dirs} and {files}" : "{dirs} und {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n versteckten eingeschlossen","%n versteckten eingeschlossen"],
    "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
    "New" : "Neu",
    "\"{name}\" is an invalid file name." : "»{name}« ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ ist kein erlaubter Dateityp",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Your storage is full, files can not be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Dein Speicher ist fast voll ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["stimmt mit '{filter}' überein","stimmen mit '{filter}' überein"],
    "View in folder" : "In Ordner anzeigen",
    "Copied!" : "Kopiert!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Nutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
    "Path" : "Pfad",
    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
    "Favorited" : "Favorisiert",
    "Favorite" : "Favorit",
    "New folder" : "Neuer Ordner",
    "Upload file" : "Datei hochladen",
    "Not favorited" : "Nicht favorisiert",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
    "Added to favorites" : "Zu den Favoriten hinzugefügt",
    "Removed from favorites" : "Aus den Favoriten entfernt",
    "You added {file} to your favorites" : "Du hast {file} zu Deinen Favoriten hinzugefügt",
    "You removed {file} from your favorites" : "Du hast {file} aus Deinen Favoriten entfernt",
    "File changes" : "Dateiänderungen",
    "Created by {user}" : "Erstellt durch {user}",
    "Changed by {user}" : "Geändert durch {user}",
    "Deleted by {user}" : "Gelöscht durch {user}",
    "Restored by {user}" : "Wiederhergestellt durch {user}",
    "Renamed by {user}" : "Umbenannt durch {user}",
    "Moved by {user}" : "Verschoben durch {user}",
    "\"remote user\"" : "„Externer Benutzer“",
    "You created {file}" : "Du hast {file} erstellt",
    "{user} created {file}" : "{user} hat {file} erstellt",
    "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
    "You changed {file}" : "Du hast {file} geändert",
    "{user} changed {file}" : "{user} hat {file} geändert",
    "You deleted {file}" : "Du hast {file} gelöscht",
    "{user} deleted {file}" : "{user} hat {file} gelöscht",
    "You restored {file}" : "Du hast {file} wiederhergestellt",
    "{user} restored {file}" : "{user} hat {file} wiederhergestellt",
    "You renamed {oldfile} to {newfile}" : "Du hast {oldfile} in {newfile} umbenannt",
    "{user} renamed {oldfile} to {newfile}" : "{user} hat {oldfile} in {newfile} umbenannt",
    "You moved {oldfile} to {newfile}" : "Du hast {oldfile} nach {newfile} verschoben",
    "{user} moved {oldfile} to {newfile}" : "{user} hat {oldfile} nach {newfile} verschoben",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde Deinen <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Eine Datei oder Ordner wurde <strong>geändert</strong> oder <strong>umbenannt</strong>",
    "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Eine Datei oder ein Ordner wurde <strong>gelöscht</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Benachrichtigungen über Neues und Änderungen auf Deine <strong>favorisierten Dateien</strong> beschränken <em>(nur im Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Eine Datei oder ein Ordner wurde <strong>wiederhergestellt</strong>",
    "Unlimited" : "Unbegrenzt",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "File handling" : "Dateibehandlung",
    "Maximum upload size" : "Maximale Upload-Größe",
    "max. possible: " : "maximal möglich:",
    "Save" : "Speichern",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Mit PHP-FPM kann es bis zu 5 Minuten dauern, bis die Einstellungen übernommen werden.",
    "Missing permissions to edit from here." : "Fehlende Berechtigungen, um dies von hier aus zu bearbeiten.",
    "%s of %s used" : "%s von %s verwendet",
    "%s used" : "%s verwendet",
    "Settings" : "Einstellungen",
    "Show hidden files" : "Versteckte Dateien anzeigen",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Diese Adresse benutzen, um <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">über WebDAV auf Deine Dateien zuzugreifen</a>",
    "Cancel upload" : "Hochladen abbrechen",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Inhalte hochladen oder mit deinen Geräten synchronisieren!",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "No favorites yet" : "Noch keine Favoriten vorhanden",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
    "Shared with you" : "Mit Dir geteilt",
    "Shared with others" : "Mit anderen geteilt",
    "Shared by link" : "Über einen Link geteilt",
    "Tags" : "Tags",
    "Deleted files" : "Gelöschte Dateien",
    "Text file" : "Textdatei",
    "New text file.txt" : "Neue Textdatei file.txt",
    "Uploading..." : "Hochladen…",
    "..." : "…",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} Stunde verbleibend","Noch {hours}:{minutes}:{seconds} Stunden"],
    "{hours}:{minutes}h" : "{hours}:{minutes} Std.",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} Minute verbleibend","Noch {minutes}:{seconds} Minuten"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} Sekunde verbleibend","Noch {seconds} Sekunden"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Gleich fertig…",
    "Soon..." : "Bald…",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dateiupload läuft. Wenn die Seite jetzt verlassen wird, bricht der Upload ab.",
    "Move" : "Verschieben",
    "Copy local link" : "Lokalen Link kopieren",
    "Folder" : "Ordner",
    "Upload" : "Hochladen",
    "A new file or folder has been <strong>deleted</strong>" : "Eine neue Datei oder Ordner wurde  <strong>gelöscht</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Neue Datei oder Ordner wurde <strong>wiederhergestellt</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Diese Adresse benutzen, um <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">über WebDAV auf Deine Dateien zuzugreifen</a>",
    "No favorites" : "Keine Favoriten"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/de.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
    "Storage invalid" : "Speicher ungültig",
    "Unknown error" : "Unbekannter Fehler",
    "All files" : "Alle Dateien",
    "Recent" : "Aktuelle",
    "File could not be found" : "Datei konnte nicht gefunden werden",
    "Home" : "Home",
    "Close" : "Schließen",
    "Favorites" : "Favoriten",
    "Could not create folder \"{dir}\"" : "Der Ordner konnte nicht erstellt werden \"{dir}\"",
    "Upload cancelled." : "Hochladen abgebrochen.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Die Datei {filename} kann nicht hochgeladen werden, da sie entweder ein Verzeichnis oder 0 Bytes groß ist",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nicht genügend freier Speicherplatz, Du möchtest{size1} hochladen, es sind jedoch nur noch {size2} verfügbar.",
    "Target folder \"{dir}\" does not exist any more" : "Ziel-Verzeichnis \"{dir}\" existiert nicht mehr",
    "Not enough free space" : "Nicht genügend freier Speicherplatz",
    "Uploading …" : "Lade hoch...",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} von {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Zielordner existiert nicht mehr",
    "Error when assembling chunks, status code {status}" : "Fehler beim Zusammenführen der Teile (Chunks), Fehlermeldung {status}",
    "Actions" : "Aktionen",
    "Download" : "Herunterladen",
    "Rename" : "Umbenennen",
    "Move or copy" : "Verschieben oder kopieren",
    "Target folder" : "Zielordner",
    "Delete" : "Löschen",
    "Disconnect storage" : "Speicher trennen",
    "Unshare" : "Freigabe aufheben",
    "Could not load info for file \"{file}\"" : "Die Informationen zur Datei \"{file}\" konnten nicht geladen werden",
    "Files" : "Dateien",
    "Details" : "Details",
    "Select" : "Auswählen",
    "Pending" : "Ausstehend",
    "Unable to determine date" : "Datum konnte nicht ermittelt werden",
    "This operation is forbidden" : "Diese Operation ist nicht erlaubt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Dieses Verzeichnis ist nicht verfügbar, bitte die Logdateien überprüfen oder den Administrator kontaktieren.",
    "Could not move \"{file}\", target exists" : "\"{file}\" konnte nicht verschoben werden, Ziel existiert bereits",
    "Could not move \"{file}\"" : "\"{file}\" konnte nicht verschoben werden",
    "Could not copy \"{file}\", target exists" : "\"{file}\" konnte nicht kopiert werden, Ziel existiert bereits",
    "Could not copy \"{file}\"" : "\"{file}\" konnte nicht kopiert werden",
    "Copied {origin} inside {destination}" : "{origin} wurde nach {destination} kopiert",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} und {nbfiles} weitere Dateien wurden nach {destination} kopiert",
    "{newName} already exists" : "{newName} existiert bereits",
    "Could not rename \"{fileName}\", it does not exist any more" : "\"{fileName}\" konnte nicht umbenannt werden, da sie nicht mehr existiert",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Der Name \"{targetName}\" wird bereits bereits in diesem Ordner benutzt \"{dir}\". Bitte einen anderen Namen verwenden.",
    "Could not rename \"{fileName}\"" : "Die Datei konnte nicht umbenannt werden \"{fileName}\"",
    "Could not create file \"{file}\"" : "Die Datei konnte nicht erstellt werden \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Die Datei \"{file}\" konnte nicht erstellt werden , da diese bereits existiert.",
    "Could not create folder \"{dir}\" because it already exists" : "Der Ordner \"{dir}\" konnte nicht erstellt werden , da dieser bereits existiert",
    "Error deleting file \"{fileName}\"." : "Fehler beim Löschen der Datei \"{fileName}\"",
    "No search results in other folders for {tag}{filter}{endtag}" : "Keine Suchergebnisse in anderen Ordnern für {tag}{filter}{endtag}",
    "Name" : "Name",
    "Size" : "Größe",
    "Modified" : "Geändert",
    "_%n folder_::_%n folders_" : ["%n Ordner","%n Ordner"],
    "_%n file_::_%n files_" : ["%n Datei","%n Dateien"],
    "{dirs} and {files}" : "{dirs} und {files}",
    "_including %n hidden_::_including %n hidden_" : ["%n versteckten eingeschlossen","%n versteckten eingeschlossen"],
    "You don’t have permission to upload or create files here" : "Du hast keine Berechtigung, hier Dateien hochzuladen oder zu erstellen",
    "_Uploading %n file_::_Uploading %n files_" : ["%n Datei wird hochgeladen","%n Dateien werden hochgeladen"],
    "New" : "Neu",
    "{used} of {quota} used" : "{used} von {quota} verwendet",
    "{used} used" : "{used} verwendet",
    "\"{name}\" is an invalid file name." : "»{name}« ist kein gültiger Dateiname.",
    "File name cannot be empty." : "Der Dateiname darf nicht leer sein.",
    "\"/\" is not allowed inside a file name." : "\"/\" ist innerhalb eines Dateinamens nicht erlaubt.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ ist kein erlaubter Dateityp",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Der Speicher von {owner} ist voll, Dateien können nicht mehr aktualisiert oder synchronisiert werden!",
    "Your storage is full, files can not be updated or synced anymore!" : "Dein Speicher ist voll, daher können keine Dateien mehr aktualisiert oder synchronisiert werden!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Der Speicher von {owner} ist beinahe voll ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Dein Speicher ist fast voll ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["stimmt mit '{filter}' überein","stimmen mit '{filter}' überein"],
    "View in folder" : "In Ordner anzeigen",
    "Copied!" : "Kopiert!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Direkten Link kopieren (funktioniert nur für Nutzer, die Zugriff auf diese(n) Datei/Ordner haben)",
    "Path" : "Pfad",
    "_%n byte_::_%n bytes_" : ["%n Byte","%n Bytes"],
    "Favorited" : "Favorisiert",
    "Favorite" : "Favorit",
    "New folder" : "Neuer Ordner",
    "Upload file" : "Datei hochladen",
    "Not favorited" : "Nicht favorisiert",
    "Remove from favorites" : "Von Favoriten entfernen",
    "Add to favorites" : "Zu den Favoriten hinzufügen",
    "An error occurred while trying to update the tags" : "Es ist ein Fehler beim Aktualisieren der Tags aufgetreten",
    "Added to favorites" : "Zu den Favoriten hinzugefügt",
    "Removed from favorites" : "Aus den Favoriten entfernt",
    "You added {file} to your favorites" : "Du hast {file} zu Deinen Favoriten hinzugefügt",
    "You removed {file} from your favorites" : "Du hast {file} aus Deinen Favoriten entfernt",
    "File changes" : "Dateiänderungen",
    "Created by {user}" : "Erstellt durch {user}",
    "Changed by {user}" : "Geändert durch {user}",
    "Deleted by {user}" : "Gelöscht durch {user}",
    "Restored by {user}" : "Wiederhergestellt durch {user}",
    "Renamed by {user}" : "Umbenannt durch {user}",
    "Moved by {user}" : "Verschoben durch {user}",
    "\"remote user\"" : "„Externer Benutzer“",
    "You created {file}" : "Du hast {file} erstellt",
    "{user} created {file}" : "{user} hat {file} erstellt",
    "{file} was created in a public folder" : "{file} wurde in einem öffentlichen Ordner erstellt",
    "You changed {file}" : "Du hast {file} geändert",
    "{user} changed {file}" : "{user} hat {file} geändert",
    "You deleted {file}" : "Du hast {file} gelöscht",
    "{user} deleted {file}" : "{user} hat {file} gelöscht",
    "You restored {file}" : "Du hast {file} wiederhergestellt",
    "{user} restored {file}" : "{user} hat {file} wiederhergestellt",
    "You renamed {oldfile} to {newfile}" : "Du hast {oldfile} in {newfile} umbenannt",
    "{user} renamed {oldfile} to {newfile}" : "{user} hat {oldfile} in {newfile} umbenannt",
    "You moved {oldfile} to {newfile}" : "Du hast {oldfile} nach {newfile} verschoben",
    "{user} moved {oldfile} to {newfile}" : "{user} hat {oldfile} nach {newfile} verschoben",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Eine Datei wurde Deinen <strong>Favoriten</strong> hinzugefügt oder daraus entfernt",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Eine Datei oder Ordner wurde <strong>geändert</strong> oder <strong>umbenannt</strong>",
    "A new file or folder has been <strong>created</strong>" : "Eine neue Datei oder ein neuer Ordner wurde <strong>erstellt</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Eine Datei oder ein Ordner wurde <strong>gelöscht</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Benachrichtigungen über Neues und Änderungen auf Deine <strong>favorisierten Dateien</strong> beschränken <em>(nur im Stream)</em>",
    "A file or folder has been <strong>restored</strong>" : "Eine Datei oder ein Ordner wurde <strong>wiederhergestellt</strong>",
    "Unlimited" : "Unbegrenzt",
    "Upload (max. %s)" : "Hochladen (max. %s)",
    "File handling" : "Dateibehandlung",
    "Maximum upload size" : "Maximale Upload-Größe",
    "max. possible: " : "maximal möglich:",
    "Save" : "Speichern",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Mit PHP-FPM kann es bis zu 5 Minuten dauern, bis die Einstellungen übernommen werden.",
    "Missing permissions to edit from here." : "Fehlende Berechtigungen, um dies von hier aus zu bearbeiten.",
    "%s of %s used" : "%s von %s verwendet",
    "%s used" : "%s verwendet",
    "Settings" : "Einstellungen",
    "Show hidden files" : "Versteckte Dateien anzeigen",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Diese Adresse benutzen, um <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">über WebDAV auf Deine Dateien zuzugreifen</a>",
    "Cancel upload" : "Hochladen abbrechen",
    "No files in here" : "Keine Dateien vorhanden",
    "Upload some content or sync with your devices!" : "Inhalte hochladen oder mit deinen Geräten synchronisieren!",
    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
    "Select all" : "Alle auswählen",
    "Upload too large" : "Der Upload ist zu groß",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
    "No favorites yet" : "Noch keine Favoriten vorhanden",
    "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die als Favoriten markiert werden, erscheinen hier",
    "Shared with you" : "Mit Dir geteilt",
    "Shared with others" : "Mit anderen geteilt",
    "Shared by link" : "Über einen Link geteilt",
    "Tags" : "Tags",
    "Deleted files" : "Gelöschte Dateien",
    "Text file" : "Textdatei",
    "New text file.txt" : "Neue Textdatei file.txt",
    "Uploading..." : "Hochladen…",
    "..." : "…",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} Stunde verbleibend","Noch {hours}:{minutes}:{seconds} Stunden"],
    "{hours}:{minutes}h" : "{hours}:{minutes} Std.",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} Minute verbleibend","Noch {minutes}:{seconds} Minuten"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} Sekunde verbleibend","Noch {seconds} Sekunden"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Gleich fertig…",
    "Soon..." : "Bald…",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Dateiupload läuft. Wenn die Seite jetzt verlassen wird, bricht der Upload ab.",
    "Move" : "Verschieben",
    "Copy local link" : "Lokalen Link kopieren",
    "Folder" : "Ordner",
    "Upload" : "Hochladen",
    "A new file or folder has been <strong>deleted</strong>" : "Eine neue Datei oder Ordner wurde  <strong>gelöscht</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Neue Datei oder Ordner wurde <strong>wiederhergestellt</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Diese Adresse benutzen, um <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">über WebDAV auf Deine Dateien zuzugreifen</a>",
    "No favorites" : "Keine Favoriten"
},
"nplurals=2; plural=(n != 1);");
